@@ -41,7 +41,7 @@ def test_images(backend, server, items):
     with mock.patch.object(backend, 'client') as m:
         m.servers.return_value = Future.fromvalue([server])
         m.server.return_value = Future.fromvalue(server)
-        m.search.return_value = Future.fromvalue(items)
+        m.search.return_value = Future.fromvalue([items, False])
         assert backend.library.get_images(item['URI'] for item in items) == {
             items[0]['URI']: (models.Image(uri=items[0]['AlbumArtURL']),),
             items[1]['URI']: tuple()
