@@ -11,6 +11,9 @@ BASEPATH = '/com/intel/dLeynaServer/server/0'
 
 ALBUM_TYPE = 'container.album.musicAlbum'
 ARTIST_TYPE = 'container.person.musicArtist'
+PLAYLIST_TYPE = 'container.playlistContainer'
+AUDIO_BOOK_TYPE = 'item.audioItem.audioBook'
+AUDIO_BROADCAST_TYPE = 'item.audioItem.audioBroadcast'
 
 
 def test_album_ref():
@@ -31,7 +34,7 @@ def test_artist_ref():
     }) == Ref.artist(uri=BASEURI+'/foo', name='Foo')
 
 
-def test_track_ref():
+def test_music_ref():
     assert translator.ref({
         'DisplayName': 'Foo',
         'URI': BASEURI + '/foo',
@@ -39,7 +42,25 @@ def test_track_ref():
     }) == Ref.track(uri=BASEURI+'/foo', name='Foo')
 
 
-def test_directory_ref():
+def test_audio_book_ref():
+    assert translator.ref({
+        'DisplayName': 'Foo',
+        'URI': BASEURI + '/foo',
+        'Type': 'audio',
+        'TypeEx': AUDIO_BOOK_TYPE
+    }) == Ref.track(uri=BASEURI+'/foo', name='Foo')
+
+
+def test_audio_broadcast_ref():
+    assert translator.ref({
+        'DisplayName': 'Foo',
+        'URI': BASEURI + '/foo',
+        'Type': 'audio',
+        'TypeEx': AUDIO_BROADCAST_TYPE
+    }) == Ref.track(uri=BASEURI+'/foo', name='Foo')
+
+
+def test_container_ref():
     assert translator.ref({
         'DisplayName': 'Foo',
         'URI': BASEURI + '/foo',
@@ -74,6 +95,15 @@ def test_artist():
     }) == Artist(uri=BASEURI+'/foo', name='Foo')
 
 
+def test_playlist():
+    assert translator.ref({
+        'DisplayName': 'Foo',
+        'URI': BASEURI + '/foo',
+        'Type': 'container',
+        'TypeEx': PLAYLIST_TYPE
+    }) == Ref.directory(uri=BASEURI+'/foo', name='Foo')
+
+
 def test_track():
     assert translator.model({
         'DisplayName': 'Foo',
@@ -83,6 +113,24 @@ def test_track():
     }) == Track(uri=BASEURI+'/foo', name='Foo', album=Album(name='Bar'))
 
 
+def test_audio_book():
+    assert translator.model({
+        'DisplayName': 'Foo',
+        'URI': BASEURI + '/foo',
+        'Type': 'audio',
+        'TypeEx': AUDIO_BOOK_TYPE
+    }) == Track(uri=BASEURI+'/foo', name='Foo')
+
+
+def test_audio_broadcast():
+    assert translator.model({
+        'DisplayName': 'Foo',
+        'URI': BASEURI + '/foo',
+        'Type': 'audio',
+        'TypeEx': AUDIO_BROADCAST_TYPE
+    }) == Track(uri=BASEURI+'/foo', name='Foo')
+
+
 def test_video():
     with pytest.raises(ValueError):
         translator.model({
